@@ -3,7 +3,7 @@ from paver.setuputils import setup
 
 options = environment.options
 
-VERSION = '0.4.1'
+VERSION = '0.4.2'
 
 setup(
     name='blackbelt',
@@ -15,7 +15,7 @@ setup(
     url='http://github.com/apiaryio/black-belt',
     license='MIT',
     packages=['blackbelt'],
-    install_requires=['requests', 'trello', 'PyGithub'],
+    requires=['requests', 'trello', 'PyGithub'],
     tests_require=['nose', 'virtualenv'],
     classifiers=[
         "Intended Audience :: Developers",
